# Summary
- [Foreword](./foreword.md)

# Getting started
- [Compiling](./compiling.md)
  - [Header-only support](./header-only.md)
  - [Adding to a project](./cmake.md)
- [Enumerating ports](./enumerating.md)
- [MIDI 1 in](./midi-1-in.md)
- [MIDI 1 out](./midi-1-out.md)
- [MIDI 2 in](./midi-2-in.md)
- [MIDI 2 out](./midi-2-out.md)
- [MIDI file support](./file.md)

# Advanced features
- [MIDI 2 integrations](./midi-2-integrations.md)
- [Hotplug support](./hotplug.md)
- [Error handling](./error-handling.md)
- [Custom configuration](./configuration.md)
  - [Context sharing](./context-sharing.md)
  - [External polling](./polling.md)
  - [Timestamping](./timestamping.md)
- [Queue vs callbacks](./queue.md)
- [Computer keyboard input](./keyboard.md)

# Reference
- [Backends](./backends.md)
